@@ -142,6 +142,6 @@ class CortxJupyter(ContentsManager):
             multipart_uploads=self.multipart_uploads,
             endpoint_url=self.endpoint_url
         )
-        cred_file.write(json.dumps(configuration))
+        cred_file.write(json.dumps(configuration._asdict()))
         return configuration
 
